<!DOCTYPE TS><TS>
<context>
    <name>QAccel</name>
    <message>
        <source>Space</source>
        <translation>Spazio</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tabulazione</translation>
    </message>
    <message>
        <source>Backtab</source>
        <translation>Tabulazione indietro</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Backspace</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Ritorno a capo</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Invio</translation>
    </message>
    <message>
        <source>Ins</source>
        <translation>Ins</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Canc</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Stampa</translation>
    </message>
    <message>
        <source>SysReq</source>
        <translation>SysReq</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Su</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Giù</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgSu</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgGiù</translation>
    </message>
    <message>
        <source>CapsLock</source>
        <translation>BlocMaiusc</translation>
    </message>
    <message>
        <source>NumLock</source>
        <translation>BlocNum</translation>
    </message>
    <message>
        <source>ScrollLock</source>
        <translation>BlocScorr</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Shift</source>
        <translation>Maiusc</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>F%1</source>
        <translation>F%1</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>?</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Inoltra</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arresta</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>Volume Down</source>
        <translation>Riduci volume</translation>
    </message>
    <message>
        <source>Volume Mute</source>
        <translation>Disattiva volume</translation>
    </message>
    <message>
        <source>Volume Up</source>
        <translation>Aumenta volume</translation>
    </message>
    <message>
        <source>Bass Boost</source>
        <translation>Incremento bassi</translation>
    </message>
    <message>
        <source>Bass Up</source>
        <translation>Aumenta bassi</translation>
    </message>
    <message>
        <source>Bass Down</source>
        <translation>Riduci bassi</translation>
    </message>
    <message>
        <source>Treble Up</source>
        <translation>Aumenta acuti</translation>
    </message>
    <message>
        <source>Treble Down</source>
        <translation>Riduci acuti</translation>
    </message>
    <message>
        <source>Media Play</source>
        <translation>Riproduci file multimediale</translation>
    </message>
    <message>
        <source>Media Stop</source>
        <translation>Arresta file multimediale</translation>
    </message>
    <message>
        <source>Media Previous</source>
        <translation>File multimediale precedente</translation>
    </message>
    <message>
        <source>Media Next</source>
        <translation>File multimediale successivo</translation>
    </message>
    <message>
        <source>Media Record</source>
        <translation>Registra file multimediale</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>Preferiti</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ricerca</translation>
    </message>
    <message>
        <source>Standby</source>
        <translation>Standby</translation>
    </message>
    <message>
        <source>Open URL</source>
        <translation>Apri URL</translation>
    </message>
    <message>
        <source>Launch Mail</source>
        <translation>Avvia posta</translation>
    </message>
    <message>
        <source>Launch Media</source>
        <translation>Avvia file multimediale</translation>
    </message>
    <message>
        <source>Launch (0)</source>
        <translation>Avvia (0)</translation>
    </message>
    <message>
        <source>Launch (1)</source>
        <translation>Avvia (1)</translation>
    </message>
    <message>
        <source>Launch (2)</source>
        <translation>Avvia (2)</translation>
    </message>
    <message>
        <source>Launch (3)</source>
        <translation>Avvia (3)</translation>
    </message>
    <message>
        <source>Launch (4)</source>
        <translation>Avvia (4)</translation>
    </message>
    <message>
        <source>Launch (5)</source>
        <translation>Avvia (5)</translation>
    </message>
    <message>
        <source>Launch (6)</source>
        <translation>Avvia (6)</translation>
    </message>
    <message>
        <source>Launch (7)</source>
        <translation>Avvia (7)</translation>
    </message>
    <message>
        <source>Launch (8)</source>
        <translation>Avvia (8)</translation>
    </message>
    <message>
        <source>Launch (9)</source>
        <translation>Avvia (9)</translation>
    </message>
    <message>
        <source>Launch (A)</source>
        <translation>Avvia (A)</translation>
    </message>
    <message>
        <source>Launch (B)</source>
        <translation>Avvia (B)</translation>
    </message>
    <message>
        <source>Launch (C)</source>
        <translation>Avvia (C)</translation>
    </message>
    <message>
        <source>Launch (D)</source>
        <translation>Avvia (D)</translation>
    </message>
    <message>
        <source>Launch (E)</source>
        <translation>Avvia (E)</translation>
    </message>
    <message>
        <source>Launch (F)</source>
        <translation>Avvia (F)</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>QT_LAYOUT_DIRECTION</source>
        <comment>Translate this string to the string &apos;LTR&apos; in left-to-right languages or to &apos;RTL&apos; in right-to-left languages (such as Hebrew and Arabic) to get proper widget layout.</comment>
        <translation>DIREZIONE_LAYOUT_QT</translation>
    </message>
    <message>
        <source>Executable &apos;%1&apos; requires TQt %2, found TQt %3.</source>
        <translation>Il file eseguibile &apos;%1&apos; richiede TQt %2, trovato TQt %3.</translation>
    </message>
    <message>
        <source>Incompatible TQt Library Error</source>
        <translation>Errore Libreria TQt incompatibile</translation>
    </message>
</context>
<context>
    <name>QAquaStyle</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>QColorDialog</name>
    <message>
        <source>Hu&amp;e:</source>
        <translation>To&amp;nalità:</translation>
    </message>
    <message>
        <source>&amp;Sat:</source>
        <translation>&amp;Sat:</translation>
    </message>
    <message>
        <source>&amp;Val:</source>
        <translation>&amp;Val:</translation>
    </message>
    <message>
        <source>&amp;Red:</source>
        <translation>&amp;Rid:</translation>
    </message>
    <message>
        <source>&amp;Green:</source>
        <translation>&amp;Verde:</translation>
    </message>
    <message>
        <source>Bl&amp;ue:</source>
        <translation>Bl&amp;u:</translation>
    </message>
    <message>
        <source>A&amp;lpha channel:</source>
        <translation>C&amp;anale alfa:</translation>
    </message>
    <message>
        <source>&amp;Basic colors</source>
        <translation>&amp;Colori di base</translation>
    </message>
    <message>
        <source>&amp;Custom colors</source>
        <translation>&amp;Colori personalizzati</translation>
    </message>
    <message>
        <source>&amp;Define Custom Colors &gt;&gt;</source>
        <translation>&amp;Definisci colori personalizzati &gt;&gt;</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>&amp;Add to Custom Colors</source>
        <translation>&amp;Aggiungi a colori personalizzati</translation>
    </message>
    <message>
        <source>Select color</source>
        <translation>Selezionare un colore</translation>
    </message>
</context>
<context>
    <name>QDataTable</name>
    <message>
        <source>True</source>
        <translation>Vero</translation>
    </message>
    <message>
        <source>False</source>
        <translation>Falso</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Inserisci</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>QDialog</name>
    <message>
        <source>What&apos;s This?</source>
        <translation>Che cos'è?</translation>
    </message>
</context>
<context>
    <name>QErrorMessage</name>
    <message>
        <source>&amp;Show this message again</source>
        <translation>&amp;Visualizza sempre questo messaggio</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Debug Message:</source>
        <translation>Debug messaggio:</translation>
    </message>
    <message>
        <source>Warning:</source>
        <translation>Avviso:</translation>
    </message>
    <message>
        <source>Fatal Error:</source>
        <translation>Errore irreversibile:</translation>
    </message>
</context>
<context>
    <name>QFileDialog</name>
    <message>
        <source>Copy or Move a File</source>
        <translation>Copia o sposta un file</translation>
    </message>
    <message>
        <source>Read: %1</source>
        <translation>Lettura: %1</translation>
    </message>
    <message>
        <source>Write: %1</source>
        <translation>Scrittura: %1</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>All Files (*)</source>
        <translation>Tutti i file (*)</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipo</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <source>Attributes</source>
        <translation>Attributi</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Look &amp;in:</source>
        <translation>Cerca &amp;in:</translation>
    </message>
    <message>
        <source>File &amp;name:</source>
        <translation>&amp;Nome file:</translation>
    </message>
    <message>
        <source>File &amp;type:</source>
        <translation>&amp;Tipo file:</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Indietro</translation>
    </message>
    <message>
        <source>One directory up</source>
        <translation>Su di una directory</translation>
    </message>
    <message>
        <source>Create New Folder</source>
        <translation>Crea nuova cartella</translation>
    </message>
    <message>
        <source>List View</source>
        <translation>Visualizza elenco</translation>
    </message>
    <message>
        <source>Detail View</source>
        <translation>Visualizza dettagli</translation>
    </message>
    <message>
        <source>Preview File Info</source>
        <translation>Anteprima delle informazioni sul file</translation>
    </message>
    <message>
        <source>Preview File Contents</source>
        <translation>Anteprima dei contenuti del file</translation>
    </message>
    <message>
        <source>Read-write</source>
        <translation>Lettura-scrittura</translation>
    </message>
    <message>
        <source>Read-only</source>
        <translation>Solo lettura</translation>
    </message>
    <message>
        <source>Write-only</source>
        <translation>Solo scrittura</translation>
    </message>
    <message>
        <source>Inaccessible</source>
        <translation>Inaccessibile</translation>
    </message>
    <message>
        <source>Symlink to File</source>
        <translation>Collegamento simbolico a file</translation>
    </message>
    <message>
        <source>Symlink to Directory</source>
        <translation>Collegamento simbolico a directory</translation>
    </message>
    <message>
        <source>Symlink to Special</source>
        <translation>Collegamento simbolico a speciale</translation>
    </message>
    <message>
        <source>File</source>
        <translation>File</translation>
    </message>
    <message>
        <source>Dir</source>
        <translation>Dir</translation>
    </message>
    <message>
        <source>Special</source>
        <translation>Speciale</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <source>Save As</source>
        <translation>Salva con nome</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Apri</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>&amp;Rinomina</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Elimina</translation>
    </message>
    <message>
        <source>R&amp;eload</source>
        <translation>R&amp;icarica</translation>
    </message>
    <message>
        <source>Sort by &amp;Name</source>
        <translation>Ordina per &amp;nome</translation>
    </message>
    <message>
        <source>Sort by &amp;Size</source>
        <translation>Ordina per &amp;dimensione</translation>
    </message>
    <message>
        <source>Sort by &amp;Date</source>
        <translation>Ordina per &amp;data</translation>
    </message>
    <message>
        <source>&amp;Unsorted</source>
        <translation>&amp;Non ordinato</translation>
    </message>
    <message>
        <source>Sort</source>
        <translation>Ordina</translation>
    </message>
    <message>
        <source>Show &amp;hidden files</source>
        <translation>Visualizza file &amp;nascosti</translation>
    </message>
    <message>
        <source>the file</source>
        <translation>il file</translation>
    </message>
    <message>
        <source>the directory</source>
        <translation>la directory</translation>
    </message>
    <message>
        <source>the symlink</source>
        <translation>il collegamento simbolico</translation>
    </message>
    <message>
        <source>Delete %1</source>
        <translation>Elimina %1</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Are you sure you wish to delete %1 &quot;%2&quot;?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Eliminare %1 &quot;%2&quot;?&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sì</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>New Folder 1</source>
        <translation>Nuova cartella 1</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nuova cartella</translation>
    </message>
    <message>
        <source>New Folder %1</source>
        <translation>Nuova cartella %1</translation>
    </message>
    <message>
        <source>Find Directory</source>
        <translation>Trova directory</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation>Directory</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Salva</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Errore</translation>
    </message>
    <message>
        <source>%1
File not found.
Check path and filename.</source>
        <translation>%1
File non trovato.
Controllare il percorso e il nome del file.</translation>
    </message>
    <message>
        <source>All Files (*.*)</source>
        <translation>Tutti i file (*.*)</translation>
    </message>
    <message>
        <source>Open </source>
        <translation>Apri </translation>
    </message>
    <message>
        <source>Select a Directory</source>
        <translation>Selezionare una directory</translation>
    </message>
    <message>
        <source>Directory:</source>
        <translation>Directory:</translation>
    </message>
</context>
<context>
    <name>QFont</name>
    <message>
        <source>Latin</source>
        <translation>Latino</translation>
    </message>
    <message>
        <source>Greek</source>
        <translation>Greco</translation>
    </message>
    <message>
        <source>Cyrillic</source>
        <translation>Cirillico</translation>
    </message>
    <message>
        <source>Armenian</source>
        <translation>Armeno</translation>
    </message>
    <message>
        <source>Georgian</source>
        <translation>Georgiano</translation>
    </message>
    <message>
        <source>Runic</source>
        <translation>Runico</translation>
    </message>
    <message>
        <source>Ogham</source>
        <translation>Ogham</translation>
    </message>
    <message>
        <source>Hebrew</source>
        <translation>Ebraico</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Arabo</translation>
    </message>
    <message>
        <source>Syriac</source>
        <translation>Siriaco</translation>
    </message>
    <message>
        <source>Thaana</source>
        <translation>Thaana</translation>
    </message>
    <message>
        <source>Devanagari</source>
        <translation>Devanagari</translation>
    </message>
    <message>
        <source>Bengali</source>
        <translation>Bengali</translation>
    </message>
    <message>
        <source>Gurmukhi</source>
        <translation>Gurmukhi</translation>
    </message>
    <message>
        <source>Gujarati</source>
        <translation>Gujarati</translation>
    </message>
    <message>
        <source>Oriya</source>
        <translation>Oriya</translation>
    </message>
    <message>
        <source>Tamil</source>
        <translation>Tamil</translation>
    </message>
    <message>
        <source>Telugu</source>
        <translation>Telugu</translation>
    </message>
    <message>
        <source>Kannada</source>
        <translation>Kannada</translation>
    </message>
    <message>
        <source>Malayalam</source>
        <translation>Malayalam</translation>
    </message>
    <message>
        <source>Sinhala</source>
        <translation>Sinhala</translation>
    </message>
    <message>
        <source>Thai</source>
        <translation>Tailandese</translation>
    </message>
    <message>
        <source>Lao</source>
        <translation>Lao</translation>
    </message>
    <message>
        <source>Tibetan</source>
        <translation>Tibetano</translation>
    </message>
    <message>
        <source>Myanmar</source>
        <translation>Myanmar</translation>
    </message>
    <message>
        <source>Khmer</source>
        <translation>Khmer</translation>
    </message>
    <message>
        <source>Han</source>
        <translation>Han</translation>
    </message>
    <message>
        <source>Hiragana</source>
        <translation>Hiragana</translation>
    </message>
    <message>
        <source>Katakana</source>
        <translation>Katakana</translation>
    </message>
    <message>
        <source>Hangul</source>
        <translation>Hangul</translation>
    </message>
    <message>
        <source>Bopomofo</source>
        <translation>Bopomofo</translation>
    </message>
    <message>
        <source>Yi</source>
        <translation>Yi</translation>
    </message>
    <message>
        <source>Ethiopic</source>
        <translation>Etiope</translation>
    </message>
    <message>
        <source>Cherokee</source>
        <translation>Cherokee</translation>
    </message>
    <message>
        <source>Canadian Aboriginal</source>
        <translation>Canadese degli aborigeni</translation>
    </message>
    <message>
        <source>Mongolian</source>
        <translation>Mongolo</translation>
    </message>
    <message>
        <source>Currency Symbols</source>
        <translation>Simboli di valuta</translation>
    </message>
    <message>
        <source>Letterlike Symbols</source>
        <translation>Simboli alfabetici</translation>
    </message>
    <message>
        <source>Number Forms</source>
        <translation>Formati numerici</translation>
    </message>
    <message>
        <source>Mathematical Operators</source>
        <translation>Operatori matematici</translation>
    </message>
    <message>
        <source>Technical Symbols</source>
        <translation>Simboli tecnici</translation>
    </message>
    <message>
        <source>Geometric Symbols</source>
        <translation>Simboli geometrici</translation>
    </message>
    <message>
        <source>Miscellaneous Symbols</source>
        <translation>Altri simboli</translation>
    </message>
    <message>
        <source>Enclosed and Square</source>
        <translation>Racchiuso e quadrato</translation>
    </message>
    <message>
        <source>Braille</source>
        <translation>Braille</translation>
    </message>
    <message>
        <source>Unicode</source>
        <translation>Unicode</translation>
    </message>
</context>
<context>
    <name>QFontDialog</name>
    <message>
        <source>&amp;Font</source>
        <translation>&amp;Carattere</translation>
    </message>
    <message>
        <source>Font st&amp;yle</source>
        <translation>St&amp;ile carattere</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Dimensione</translation>
    </message>
    <message>
        <source>Effects</source>
        <translation>Effetti</translation>
    </message>
    <message>
        <source>Stri&amp;keout</source>
        <translation>Barra&amp;to</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Sottolineato</translation>
    </message>
    <message>
        <source>&amp;Color</source>
        <translation>&amp;Colore</translation>
    </message>
    <message>
        <source>Sample</source>
        <translation>Esempio</translation>
    </message>
    <message>
        <source>Scr&amp;ipt</source>
        <translation>Scr&amp;ipt</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Select Font</source>
        <translation>Selezionare un carattere</translation>
    </message>
</context>
<context>
    <name>QFtp</name>
    <message>
        <source>Host %1 found</source>
        <translation>Host %1 trovato</translation>
    </message>
    <message>
        <source>Host found</source>
        <translation>Host trovato</translation>
    </message>
    <message>
        <source>Connected to host %1</source>
        <translation>Connesso all'host %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Connesso all'host</translation>
    </message>
    <message>
        <source>Connection to %1 closed</source>
        <translation>Connessione a %1 chiusa</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Connessione chiusa</translation>
    </message>
    <message>
        <source>Host %1 not found</source>
        <translation>Host %1 non trovato</translation>
    </message>
    <message>
        <source>Connection refused to host %1</source>
        <translation>Connessione rifiutata all'host %1</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Errore sconosciuto</translation>
    </message>
    <message>
        <source>Connecting to host failed:
%1</source>
        <translation>Connessione all'host non riuscita:
%1</translation>
    </message>
    <message>
        <source>Login failed:
%1</source>
        <translation>Accesso non riuscito:
%1</translation>
    </message>
    <message>
        <source>Listing directory failed:
%1</source>
        <translation>Visualizzazione dell'elenco delle directory non riuscita:
%1</translation>
    </message>
    <message>
        <source>Changing directory failed:
%1</source>
        <translation>Modifica della directory non riuscita:
%1</translation>
    </message>
    <message>
        <source>Downloading file failed:
%1</source>
        <translation>Download del file non riuscito:
%1</translation>
    </message>
    <message>
        <source>Uploading file failed:
%1</source>
        <translation>Caricamento del file non riuscito:
%1</translation>
    </message>
    <message>
        <source>Removing file failed:
%1</source>
        <translation>Rimozione del file non riuscita:
%1</translation>
    </message>
    <message>
        <source>Creating directory failed:
%1</source>
        <translation>Creazione della directory non riuscita:
%1</translation>
    </message>
    <message>
        <source>Removing directory failed:
%1</source>
        <translation>Rimozione della directory non riuscita:
%1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connesso</translation>
    </message>
    <message>
        <source>Connection refused for data connection</source>
        <translation>Connessione rifiutata per connessione dati</translation>
    </message>
</context>
<context>
    <name>QHeader</name>
    <message>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>QHttp</name>
    <message>
        <source>Connection refused</source>
        <translation>Connessione rifiutata</translation>
    </message>
    <message>
        <source>Host %1 not found</source>
        <translation>Host %1 non trovato</translation>
    </message>
    <message>
        <source>Wrong content length</source>
        <translation>Lunghezza contenuto errata</translation>
    </message>
    <message>
        <source>HTTP request failed</source>
        <translation>Richiesta http non riuscita</translation>
    </message>
    <message>
        <source>Host %1 found</source>
        <translation>Host %1 trovato</translation>
    </message>
    <message>
        <source>Host found</source>
        <translation>Host trovato</translation>
    </message>
    <message>
        <source>Connected to host %1</source>
        <translation>Connesso all'host %1</translation>
    </message>
    <message>
        <source>Connected to host</source>
        <translation>Connesso all'host</translation>
    </message>
    <message>
        <source>Connection to %1 closed</source>
        <translation>Connessione all'host %1 chiusa</translation>
    </message>
    <message>
        <source>Connection closed</source>
        <translation>Connessione chiusa</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Errore sconosciuto</translation>
    </message>
    <message>
        <source>Request aborted</source>
        <translation>Richiesta annullata</translation>
    </message>
    <message>
        <source>No server set to connect to</source>
        <translation>Nessun server disponibile per la connessione</translation>
    </message>
    <message>
        <source>Server closed connection unexpectedly</source>
        <translation>Connessione server chiusa in modo inatteso</translation>
    </message>
    <message>
        <source>Invalid HTTP response header</source>
        <translation>Intestazione risposta http non valida</translation>
    </message>
    <message>
        <source>Invalid HTTP chunked body</source>
        <translation>Seziono corpo HTTP non valida</translation>
    </message>
</context>
<context>
    <name>QInputDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Ripeti</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Ta&amp;glia</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleziona tutto</translation>
    </message>
</context>
<context>
    <name>QLocalFs</name>
    <message>
        <source>Could not rename
%1
to
%2</source>
        <translation>Impossibile rinominare
%1
in
%2</translation>
    </message>
    <message>
        <source>Could not open
%1</source>
        <translation>Impossibile aprire
%1</translation>
    </message>
    <message>
        <source>Could not write
%1</source>
        <translation>Impossibile scrivere
%1</translation>
    </message>
    <message>
        <source>Could not read directory
%1</source>
        <translation>Impossibile leggere la directory
%1</translation>
    </message>
    <message>
        <source>Could not create directory
%1</source>
        <translation>Impossibile creare la directory
%1</translation>
    </message>
    <message>
        <source>Could not remove file or directory
%1</source>
        <translation>Impossibile rimuovere il file o la directory
%1</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Line up</source>
        <translation>Su di una riga</translation>
    </message>
    <message>
        <source>Customize...</source>
        <translation>Personalizza...</translation>
    </message>
</context>
<context>
    <name>QMenuBar</name>
    <message>
        <source>About</source>
        <translation>Informazioni su</translation>
    </message>
    <message>
        <source>Config</source>
        <translation>Config</translation>
    </message>
    <message>
        <source>Preference</source>
        <translation>Preferenza</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Setting</source>
        <translation>Impostazione</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Configura</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Sì</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;No</translation>
    </message>
    <message>
        <source>&amp;Abort</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Riprova</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignora</translation>
    </message>
    <message>
        <source>&lt;h3&gt;About Qt&lt;/h3&gt;&lt;p&gt;This program uses TQt version %1.&lt;/p&gt;&lt;p&gt;Qt is a C++ toolkit for multiplatform GUI &amp;amp; application development.&lt;/p&gt;&lt;p&gt;Qt provides single-source portability across MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux, and all major commercial Unix variants.&lt;br&gt;Qt is also available for embedded devices.&lt;/p&gt;&lt;p&gt;Qt is a Trolltech product. See &lt;tt&gt;https://trinitydesktop.org/docs/qt3/&lt;/tt&gt; for more information.&lt;/p&gt;</source>
        <translation>&lt;h3&gt;Informazioni su Qt&lt;/h3&gt;&lt;p&gt;Questo programma usa la versione di TQt %1.&lt;/p&gt;&lt;p&gt;Qt è un kit di strumenti C++ per lo sviluppo di applicazioni GUI &amp;amp; multi-piattaforma.&lt;/p&gt;&lt;p&gt;Qt consente di creare un'unica interfaccia portatile compatibile con MS&amp;nbsp;Windows, Mac&amp;nbsp;OS&amp;nbsp;X, Linux e le principali varianti commerciali di Unix.&lt;br&gt;Qt è disponibile anche per le periferiche incorporate.&lt;/p&gt;&lt;p&gt;Qt è un prodotto di Trolltech. Per ulteriori informazioni, visitare la pagina Web &lt;tt&gt;https://trinitydesktop.org/docs/qt3/&lt;/tt&gt;.&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>QNetworkProtocol</name>
    <message>
        <source>Operation stopped by the user</source>
        <translation>Operazione interrotta dall'utente</translation>
    </message>
</context>
<context>
    <name>QPrintDialog</name>
    <message>
        <source>locally connected</source>
        <translation>connesso localmente</translation>
    </message>
    <message>
        <source>Aliases: %1</source>
        <translation>Alias: %1</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>sconosciuto</translation>
    </message>
    <message>
        <source>Unknown Location</source>
        <translation>Posizione sconosciuta</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Printer settings</source>
        <translation>Impostazioni stampante</translation>
    </message>
    <message>
        <source>Print in color if available</source>
        <translation>Stampa a colori se disponibile</translation>
    </message>
    <message>
        <source>Print in grayscale</source>
        <translation>Stampa in scala di grigi</translation>
    </message>
    <message>
        <source>Print destination</source>
        <translation>Destinazione stampa</translation>
    </message>
    <message>
        <source>Print to printer:</source>
        <translation>Stampa su stampante:</translation>
    </message>
    <message>
        <source>Printer</source>
        <translation>Stampante</translation>
    </message>
    <message>
        <source>Host</source>
        <translation>Host</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Commento</translation>
    </message>
    <message>
        <source>Print to file:</source>
        <translation>Stampa su file:</translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation>Sfoglia...</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opzioni</translation>
    </message>
    <message>
        <source>Print all</source>
        <translation>Stampa tutto</translation>
    </message>
    <message>
        <source>Print range</source>
        <translation>Intervallo di stampa</translation>
    </message>
    <message>
        <source>From page:</source>
        <translation>Dalla pagina:</translation>
    </message>
    <message>
        <source>To page:</source>
        <translation>Alla pagina:</translation>
    </message>
    <message>
        <source>Print first page first</source>
        <translation>Stampa prima la prima pagina</translation>
    </message>
    <message>
        <source>Print last page first</source>
        <translation>Stampa prima l'ultima pagina</translation>
    </message>
    <message>
        <source>Number of copies:</source>
        <translation>Numero di copie:</translation>
    </message>
    <message>
        <source>Paper format</source>
        <translation>Formato carta</translation>
    </message>
    <message>
        <source>Portrait</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <source>Landscape</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <source>A0 (841 x 1189 mm)</source>
        <translation>A0 (841 x 1189 mm)</translation>
    </message>
    <message>
        <source>A1 (594 x 841 mm)</source>
        <translation>A1 (594 x 841 mm)</translation>
    </message>
    <message>
        <source>A2 (420 x 594 mm)</source>
        <translation>A2 (420 x 594 mm)</translation>
    </message>
    <message>
        <source>A3 (297 x 420 mm)</source>
        <translation>A3 (297 x 420 mm)</translation>
    </message>
    <message>
        <source>A4 (210x297 mm, 8.26x11.7 inches)</source>
        <translation>A4 (210x297 mm, 8,26x11,7")</translation>
    </message>
    <message>
        <source>A5 (148 x 210 mm)</source>
        <translation>A5 (148 x 210 mm)</translation>
    </message>
    <message>
        <source>A6 (105 x 148 mm)</source>
        <translation>A6 (105 x 148 mm)</translation>
    </message>
    <message>
        <source>A7 (74 x 105 mm)</source>
        <translation>A7 (74 x 105 mm)</translation>
    </message>
    <message>
        <source>A8 (52 x 74 mm)</source>
        <translation>A8 (52 x 74 mm)</translation>
    </message>
    <message>
        <source>A9 (37 x 52 mm)</source>
        <translation>A9 (37 x 52 mm)</translation>
    </message>
    <message>
        <source>B0 (1000 x 1414 mm)</source>
        <translation>B0 (1000 x 1414 mm)</translation>
    </message>
    <message>
        <source>B1 (707 x 1000 mm)</source>
        <translation>B1 (707 x 1000 mm)</translation>
    </message>
    <message>
        <source>B2 (500 x 707 mm)</source>
        <translation>B2 (500 x 707 mm)</translation>
    </message>
    <message>
        <source>B3 (353 x 500 mm)</source>
        <translation>B3 (353 x 500 mm)</translation>
    </message>
    <message>
        <source>B4 (250 x 353 mm)</source>
        <translation>B4 (250 x 353 mm)</translation>
    </message>
    <message>
        <source>B5 (176 x 250 mm, 6.93x9.84 inches)</source>
        <translation>B5 (176 x 250 mm, 6,93x9,84 pollici)</translation>
    </message>
    <message>
        <source>B6 (125 x 176 mm)</source>
        <translation>B6 (125 x 176 mm)</translation>
    </message>
    <message>
        <source>B7 (88 x 125 mm)</source>
        <translation>B7 (88 x 125 mm)</translation>
    </message>
    <message>
        <source>B8 (62 x 88 mm)</source>
        <translation>B8 (62 x 88 mm)</translation>
    </message>
    <message>
        <source>B9 (44 x 62 mm)</source>
        <translation>B9 (44 x 62 mm)</translation>
    </message>
    <message>
        <source>B10 (31 x 44 mm)</source>
        <translation>B10 (31 x 44 mm)</translation>
    </message>
    <message>
        <source>C5E (163 x 229 mm)</source>
        <translation>C5E (163 x 229 mm)</translation>
    </message>
    <message>
        <source>DLE (110 x 220 mm)</source>
        <translation>DLE (110 x 220 mm)</translation>
    </message>
    <message>
        <source>Executive (7.5x10 inches, 191x254 mm)</source>
        <translation>Executive (7,5x10 pollici, 191x254 mm)</translation>
    </message>
    <message>
        <source>Folio (210 x 330 mm)</source>
        <translation>Folio (210 x 330 mm)</translation>
    </message>
    <message>
        <source>Ledger (432 x 279 mm)</source>
        <translation>Ledger (432 x 279 mm)</translation>
    </message>
    <message>
        <source>Legal (8.5x14 inches, 216x356 mm)</source>
        <translation>Legal (8,5x14 pollici, 216x356 mm)</translation>
    </message>
    <message>
        <source>Letter (8.5x11 inches, 216x279 mm)</source>
        <translation>Letter (8,5x11 pollici, 216x279 mm)</translation>
    </message>
    <message>
        <source>Tabloid (279 x 432 mm)</source>
        <translation>Tabloid (279 x 432 mm)</translation>
    </message>
    <message>
        <source>US Common #10 Envelope (105 x 241 mm)</source>
        <translation>Busta standard USA (105 x 241 mm)</translation>
    </message>
    <message>
        <source>Setup Printer</source>
        <translation>Imposta stampante</translation>
    </message>
    <message>
        <source>PostScript Files (*.ps);;All Files (*)</source>
        <translation>File PostScript (*.ps);;Tutti i file (*)</translation>
    </message>
</context>
<context>
    <name>QProgressDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>QRegExp</name>
    <message>
        <source>no error occurred</source>
        <translation>nessun errore</translation>
    </message>
    <message>
        <source>disabled feature used</source>
        <translation>è stata usata una funzione disabilitata</translation>
    </message>
    <message>
        <source>bad char class syntax</source>
        <translation>sintassi della classe dei caratteri errata</translation>
    </message>
    <message>
        <source>bad lookahead syntax</source>
        <translation>sintassi ricerca errata</translation>
    </message>
    <message>
        <source>bad repetition syntax</source>
        <translation>sintassi ripetizioni errata</translation>
    </message>
    <message>
        <source>invalid octal value</source>
        <translation>valore ottale non valido</translation>
    </message>
    <message>
        <source>missing left delim</source>
        <translation>delimitatore sinistro mancante</translation>
    </message>
    <message>
        <source>unexpected end</source>
        <translation>fine imprevista</translation>
    </message>
    <message>
        <source>met internal limit</source>
        <translation>è stato raggiunto il limite interno</translation>
    </message>
</context>
<context>
    <name>QSql</name>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Delete this record?</source>
        <translation>Eliminare il record?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Sì</translation>
    </message>
    <message>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Inserisci</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aggiorna</translation>
    </message>
    <message>
        <source>Save edits?</source>
        <translation>Salvare le modifiche?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Conferma</translation>
    </message>
    <message>
        <source>Cancel your edits?</source>
        <translation>Annullare le modifiche?</translation>
    </message>
</context>
<context>
    <name>QTabDialog</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Applica</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>?</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Predefiniti</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>QTextEdit</name>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Ripeti</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Ta&amp;glia</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleziona tutto</translation>
    </message>
</context>
<context>
    <name>QTitleBar</name>
    <message>
        <source>System Menu</source>
        <translation>Menu di sistema</translation>
    </message>
    <message>
        <source>Shade</source>
        <translation>Aggiungi blocco</translation>
    </message>
    <message>
        <source>Unshade</source>
        <translation>Rimuovi blocco</translation>
    </message>
    <message>
        <source>Normalize</source>
        <translation>Normalizza</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Riduci a icona</translation>
    </message>
    <message>
        <source>Maximize</source>
        <translation>Ingrandisci</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
</context>
<context>
    <name>QToolBar</name>
    <message>
        <source>More...</source>
        <translation>Max...</translation>
    </message>
</context>
<context>
    <name>QUrlOperator</name>
    <message>
        <source>The protocol `%1&apos; is not supported</source>
        <translation>Protocollo `%1&apos; non supportato</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support listing directories</source>
        <translation>Il protocollo `%1&apos; non supporta la visualizzazione di elenchi di directory</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support creating new directories</source>
        <translation>Il protocollo `%1&apos; non supporta la creazione di nuove directory</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support removing files or directories</source>
        <translation>Il protocollo `%1&apos; non supporta la rimozione di file o directory</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support renaming files or directories</source>
        <translation>Il protocollo `%1&apos; non supporta la ridenominazione di file o directory</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support getting files</source>
        <translation>Il protocollo`%1&apos; non supporta l'actquisizione di file</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support putting files</source>
        <translation>Il protocollo `%1&apos; non supporta l'inserimento di file</translation>
    </message>
    <message>
        <source>The protocol `%1&apos; does not support copying or moving files or directories</source>
        <translation>Il protocollo `%1&apos; non supporta la copia o lo spostamento di file o directory</translation>
    </message>
    <message>
        <source>(unknown)</source>
        <translation>(sconosciuto)</translation>
    </message>
</context>
<context>
    <name>QWSDecoration</name>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Ripristina</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Sposta</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Dimensione</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Ri&amp;duci a icona</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>In&amp;grandisci</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Windows</translation>
    </message>
    <message>
        <source>KDE</source>
        <translation>KDE</translation>
    </message>
    <message>
        <source>KDE2</source>
        <translation>KDE2</translation>
    </message>
    <message>
        <source>BeOS</source>
        <translation>BeOS</translation>
    </message>
    <message>
        <source>Hydro</source>
        <translation>Hydro</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predefinito</translation>
    </message>
</context>
<context>
    <name>QWhatsThisButton</name>
    <message>
        <source>What&apos;s this?</source>
        <translation>Che cos'è?</translation>
    </message>
</context>
<context>
    <name>QWizard</name>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>&lt; &amp;Back</source>
        <translation>&lt; &amp;Indietro</translation>
    </message>
    <message>
        <source>&amp;Next &gt;</source>
        <translation>&amp;Prossimo &gt;</translation>
    </message>
    <message>
        <source>&amp;Finish</source>
        <translation>&amp;Fine</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;?</translation>
    </message>
</context>
<context>
    <name>QWorkspace</name>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Ripristina</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Sposta</translation>
    </message>
    <message>
        <source>&amp;Size</source>
        <translation>&amp;Dimensione</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Ri&amp;duci a icona</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>In&amp;grandisci</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <source>Stay on &amp;Top</source>
        <translation>In &amp;primo piano</translation>
    </message>
    <message>
        <source>Sh&amp;ade</source>
        <translation>Bl&amp;occa</translation>
    </message>
    <message>
        <source>%1 - [%2]</source>
        <translation>%1 - [%2]</translation>
    </message>
    <message>
        <source>Minimize</source>
        <translation>Riduci a icona</translation>
    </message>
    <message>
        <source>Restore Down</source>
        <translation>Ripristina giù</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <source>&amp;Unshade</source>
        <translation>&amp;Rimuovi blocco</translation>
    </message>
</context>
<context>
    <name>QXml</name>
    <message>
        <source>no error occurred</source>
        <translation>nessun errore</translation>
    </message>
    <message>
        <source>error triggered by consumer</source>
        <translation>errore attivato da utente</translation>
    </message>
    <message>
        <source>unexpected end of file</source>
        <translation>fine file inattesa</translation>
    </message>
    <message>
        <source>more than one document type definition</source>
        <translation>sono state trovate più definizioni per il tipo di documento</translation>
    </message>
    <message>
        <source>error occurred while parsing element</source>
        <translation>errore durante l'analisi dell'elemento</translation>
    </message>
    <message>
        <source>tag mismatch</source>
        <translation>tag non corrispondenti</translation>
    </message>
    <message>
        <source>error occurred while parsing content</source>
        <translation>errore durante l'analisi del contenuto</translation>
    </message>
    <message>
        <source>unexpected character</source>
        <translation>carattere imprevisto</translation>
    </message>
    <message>
        <source>invalid name for processing instruction</source>
        <translation>nome non valido per l'elaborazione dell'istruzione</translation>
    </message>
    <message>
        <source>version expected while reading the XML declaration</source>
        <translation>versione attesa durante la lettura della dichiarazione XML</translation>
    </message>
    <message>
        <source>wrong value for standalone declaration</source>
        <translation>valore errato per dichiarazione indipendente</translation>
    </message>
    <message>
        <source>encoding declaration or standalone declaration expected while reading the XML declaration</source>
        <translation>attesa dichiarazione di codifica o indipendente durante la lettura della dichiarazione XML</translation>
    </message>
    <message>
        <source>standalone declaration expected while reading the XML declaration</source>
        <translation>attesa dichiarazione indipendente durante la lettura della dichiarazione XML</translation>
    </message>
    <message>
        <source>error occurred while parsing document type definition</source>
        <translation>errore durante l'analisi della definizione del tipo di documento</translation>
    </message>
    <message>
        <source>letter is expected</source>
        <translation>prevista lettera</translation>
    </message>
    <message>
        <source>error occurred while parsing comment</source>
        <translation>errore durante l'analisi del commento</translation>
    </message>
    <message>
        <source>error occurred while parsing reference</source>
        <translation>errore durante l'analisi del riferimento</translation>
    </message>
    <message>
        <source>internal general entity reference not allowed in DTD</source>
        <translation>riferimento interno a entità generica non consentito in DTD</translation>
    </message>
    <message>
        <source>external parsed general entity reference not allowed in attribute value</source>
        <translation>riferimento esterno a entità generale analizzata non consentito nel valore dell'attributo</translation>
    </message>
    <message>
        <source>external parsed general entity reference not allowed in DTD</source>
        <translation>riferimento esterno a entità generale analizzata non consentito in DTD</translation>
    </message>
    <message>
        <source>unparsed entity reference in wrong context</source>
        <translation>riferimento entità non analizzata nel contesto errato</translation>
    </message>
    <message>
        <source>recursive entities</source>
        <translation>entità ricorrenti</translation>
    </message>
    <message>
        <source>error in the text declaration of an external entity</source>
        <translation>errore nella dichiarazione testuale di un'entità esterna</translation>
    </message>
</context>
<context>
    <name>QtMultiLineEdit</name>
    <message>
        <source>Undo</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>Ripeti</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>Taglia</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Incolla</translation>
    </message>
    <message>
        <source>Paste special...</source>
        <translation>Incolla speciale...</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <source>Select All</source>
        <translation>Seleziona tutto</translation>
    </message>
</context>
</TS>


